# ListFileShareServicesResponse

Response object for listing FileShareServices
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**file_share_services** | [**list[FileShareService]**](FileShareService.md) | List of FileShareServices | [optional] 
**limit** | **int** | The maximum number of records returned in the response. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


